#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.7
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import inquirer from 'inquirer';
import { getProperty } from 'js-cool';
import { getCurrentBranch } from '@gitmars/git';
import { createArgs } from '@gitmars/utils';
import lang from './common/local.mjs';
import * as index from './go/index.mjs';
import { cmdConfig } from './conf/go.mjs';

const { t } = lang;
const { green, red } = chalk;
const { args, options } = cmdConfig;
program.name("gitm go").usage("[command]").description(t("Intelligent guessing of the action you want to perform"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (command) => {
  const current = getCurrentBranch();
  sh.echo(
    green(
      t("Current branch is {current}, I suspect you may want to do the following: ", {
        current
      })
    )
  );
  if (command) {
    const cmd = getProperty(index, command);
    if (!cmd) {
      sh.echo(
        red(
          t("The command you entered was not found and may not be supported at this time")
        )
      );
      process.exit(1);
    }
    cmd();
  } else {
    inquirer.prompt({
      type: "list",
      name: "command",
      message: t("Please select the operation you want?"),
      default: "combine",
      choices: [
        new inquirer.Separator(" === 1. " + t("Gitmars Workflow") + " === "),
        "combine",
        "end",
        "update",
        "build",
        "start",
        "undo",
        "redo",
        "admin.publish",
        "admin.update",
        "admin.create",
        "admin.clean",
        new inquirer.Separator(" === 2. " + t("Advanced Tools") + " === "),
        "branch",
        "copy",
        "get",
        "save",
        "cleanbranch",
        "clean",
        "revert",
        "link",
        "unlink",
        "postmsg",
        new inquirer.Separator(" === " + t("Exit") + " === "),
        "exit",
        new inquirer.Separator()
      ],
      filter: (val) => {
        return val;
      }
    }).then((answers) => {
      if (answers.command === "exit") {
        sh.echo(green(t("exited")));
        process.exit(0);
      }
      sh.echo(
        green(
          t("You have selected the {something} command", {
            something: answers.command
          })
        )
      );
      getProperty(index, answers.command)();
    });
  }
});
program.parse(process.argv);
